diff src/ft.h @ 10654:f2e86683cafc

[gaim-migrate @ 12182] sf patch #1152664, from Richard Laager This patches does three things: First, it uses aliases in file transfer messages whenever possible. Second, it fixes the case where file transfer completion messages are not showing for MSN. Third, it makes the wording more consistent: Canceled is used to describe cases when the file transfer was actively canceled by either party. Failed is used otherwise. Aborted is no longer used at all. Previously, aborted was used in some places while failed was used under the same circumstances in other places. Also, in the file transfer box, canceled was used in one place for remotely or locally canceled files while in another place in the same box canceled was only used for locally canceled files (failed was used for remotely canceled files). committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Sun, 06 Mar 2005 00:23:54 +0000
parents cee849d17167
children 2c21bffa8200
line wrap: on
line diff
--- a/src/ft.h	Sun Mar 06 00:10:54 2005 +0000
+++ b/src/ft.h	Sun Mar 06 00:23:54 2005 +0000
@@ -522,14 +522,15 @@
  * Displays a file transfer-related error message.
  *
  * This is a wrapper around gaim_notify_error(), which automatically
- * specifies a title ("File transfer to <i>user</i> aborted" or
- * "File Transfer from <i>user</i> aborted").
+ * specifies a title ("File transfer to <i>user</i> failed" or
+ * "File Transfer from <i>user</i> failed").
  *
  * @param type The type of file transfer.
  * @param who  The user on the other end of the transfer.
  * @param msg  The message to display.
  */
-void gaim_xfer_error(GaimXferType type, const char *who, const char *msg);
+void gaim_xfer_error(GaimXferType type, GaimAccount *account, const char *who, const char *msg);
 
 /**
  * Updates file transfer progress.
@@ -522,14 +522,15 @@
  *
- * @param type The type of file transfer.
- * @param who  The user on the other end of the transfer.
- * @param msg  The message to display.
+ * @param type    The type of file transfer.
+ * @param account The account sending or receiving the file.
+ * @param who     The user on the other end of the transfer.
+ * @param msg     The message to display.
  */